"""AUACM top package"""

import auacm.common, auacm.main, auacm.user, auacm.problems, auacm.submit, auacm.competition, auacm.exceptions
from auacm.common import DEBUG, BASE_URL, logo, session
import auacm.utils

# Package metadata
__description__ = 'A command line interface to the Auburn ACM website'
__license__ = 'MIT'
__uri__ = 'https://github.com/BrandonLMorris/auacm-cli'
__version__ = '0.3'
__author__ = 'Brandon Morris'
__email__ = 'brandon.morris95@gmail.com'

